@@ -7,10 +7,10 @@ class SQLLexer(Lexer):
     ignore = ' \t\n'
 
     tokens = {
-        # Mindsdb Commands
+        USE,
 
         # SELECT Keywords
-        SELECT, DISTINCT, FROM, WHERE, AS,
+        WITH, SELECT, DISTINCT, FROM, WHERE, AS,
         LIMIT, OFFSET, ASC, DESC, NULLS_FIRST, NULLS_LAST,
         GROUP_BY, HAVING, ORDER_BY,
         STAR,
@@ -40,6 +40,7 @@ class SQLLexer(Lexer):
     DESC = r'\bDESC\b'
     NULLS_FIRST = r'\bNULLS FIRST\b'
     NULLS_LAST = r'\bNULLS LAST\b'
+    WITH = r'\bWITH\b'
     SELECT = r'\bSELECT\b'
     DISTINCT = r'\bDISTINCT\b'
     FROM = r'\bFROM\b'
